==> ejc-bfyjerp-api-3.0.0-20241108.084011-22-sources.jar: com/ejianc/business/project/LeaveSiteVO.java <==
package com.ejianc.business.project;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 项目基本信息管理-人员撤场
 * 
 * @author generator
 * 
 */
public class LeaveSiteVO extends BaseVO {

    private static final long serialVersionUID = 6611538439406387458L;

    private String billCode; //编码
    private Long projectId; // 项目Id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目部Id
    private String orgCode; // 项目部编码
    private String orgName; // 项目部名称
    private Long parentOrgId; // 项目部所属组织Id
    private String parentOrgCode; // 项目部所属组织编码
    private String parentOrgName; // 项目部所属组织名称
    private Long onSiteEmployeeId; // 人员id
    private String onSiteEmployeeName; // 人员名称
    private String onSiteEmployeeCode; // 人员编码
    private String area; // 地区
    private Long onSitePostId; // 驻场岗位id
    private String onSitePostName; // 驻场岗位名称
    private BigDecimal dailyMny; // 金额(天)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date startDate; // 开始时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date endDate; // 结束时间
    private Long onSiteId; // 驻场单id
    private Integer onSiteDays; // 驻场天数
    private BigDecimal onSiteMny; // 驻场金额
    private Long employeeId; // 编制人员id
    private String employeeName; // 编制人员名称
    private Long engineeringType; // 工程类型
    private String engineeringTypeName; //工程类型名称

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringType() {
        return engineeringType;
    }
    @ReferDeserialTransfer
    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    @ReferSerialTransfer(referCode = "bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getOnSiteEmployeeId() {
        return onSiteEmployeeId;
    }
    @ReferDeserialTransfer
    public void setOnSiteEmployeeId(Long onSiteEmployeeId) {
        this.onSiteEmployeeId = onSiteEmployeeId;
    }
    public String getOnSiteEmployeeName() {
        return onSiteEmployeeName;
    }

    public void setOnSiteEmployeeName(String onSiteEmployeeName) {
        this.onSiteEmployeeName = onSiteEmployeeName;
    }
    public String getOnSiteEmployeeCode() {
        return onSiteEmployeeCode;
    }

    public void setOnSiteEmployeeCode(String onSiteEmployeeCode) {
        this.onSiteEmployeeCode = onSiteEmployeeCode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    @ReferSerialTransfer(referCode = "bfyj-onsite-post")
    public Long getOnSitePostId() {
        return onSitePostId;
    }
    @ReferDeserialTransfer
    public void setOnSitePostId(Long onSitePostId) {
        this.onSitePostId = onSitePostId;
    }
    public String getOnSitePostName() {
        return onSitePostName;
    }

    public void setOnSitePostName(String onSitePostName) {
        this.onSitePostName = onSitePostName;
    }
    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    @ReferSerialTransfer(referCode = "bfyj-onsite")
    public Long getOnSiteId() {
        return onSiteId;
    }
    @ReferDeserialTransfer
    public void setOnSiteId(Long onSiteId) {
        this.onSiteId = onSiteId;
    }
    public Integer getOnSiteDays() {
        return onSiteDays;
    }

    public void setOnSiteDays(Integer onSiteDays) {
        this.onSiteDays = onSiteDays;
    }
    public BigDecimal getOnSiteMny() {
        return onSiteMny;
    }

    public void setOnSiteMny(BigDecimal onSiteMny) {
        this.onSiteMny = onSiteMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250121.081350-113-sources.jar: com/ejianc/business/project/LeaveSiteVO.java <==
package com.ejianc.business.project;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 项目基本信息管理-人员撤场
 * 
 * @author generator
 * 
 */
public class LeaveSiteVO extends BaseVO {

    private static final long serialVersionUID = 6611538439406387458L;

    private String billCode; //编码
    private Long projectId; // 项目Id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 项目部Id
    private String orgCode; // 项目部编码
    private String orgName; // 项目部名称
    private Long parentOrgId; // 项目部所属组织Id
    private String parentOrgCode; // 项目部所属组织编码
    private String parentOrgName; // 项目部所属组织名称
    private Long onSiteEmployeeId; // 人员id
    private String onSiteEmployeeName; // 人员名称
    private String onSiteEmployeeCode; // 人员编码
    private String area; // 地区
    private Long onSitePostId; // 驻场岗位id
    private String onSitePostName; // 驻场岗位名称
    private BigDecimal dailyMny; // 金额(天)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startDate; // 开始时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate; // 结束时间
    private Long onSiteId; // 驻场单id
    private Integer onSiteDays; // 驻场天数
    private BigDecimal onSiteMny; // 驻场金额
    private Long employeeId; // 编制人员id
    private String employeeName; // 编制人员名称
    private Long engineeringType; // 工程类型
    private String engineeringTypeName; //工程类型名称

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getEngineeringType() {
        return engineeringType;
    }
    @ReferDeserialTransfer
    public void setEngineeringType(Long engineeringType) {
        this.engineeringType = engineeringType;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    @ReferSerialTransfer(referCode = "bfyj-market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getOnSiteEmployeeId() {
        return onSiteEmployeeId;
    }
    @ReferDeserialTransfer
    public void setOnSiteEmployeeId(Long onSiteEmployeeId) {
        this.onSiteEmployeeId = onSiteEmployeeId;
    }
    public String getOnSiteEmployeeName() {
        return onSiteEmployeeName;
    }

    public void setOnSiteEmployeeName(String onSiteEmployeeName) {
        this.onSiteEmployeeName = onSiteEmployeeName;
    }
    public String getOnSiteEmployeeCode() {
        return onSiteEmployeeCode;
    }

    public void setOnSiteEmployeeCode(String onSiteEmployeeCode) {
        this.onSiteEmployeeCode = onSiteEmployeeCode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    @ReferSerialTransfer(referCode = "bfyj-onsite-post")
    public Long getOnSitePostId() {
        return onSitePostId;
    }
    @ReferDeserialTransfer
    public void setOnSitePostId(Long onSitePostId) {
        this.onSitePostId = onSitePostId;
    }
    public String getOnSitePostName() {
        return onSitePostName;
    }

    public void setOnSitePostName(String onSitePostName) {
        this.onSitePostName = onSitePostName;
    }
    public BigDecimal getDailyMny() {
        return dailyMny;
    }

    public void setDailyMny(BigDecimal dailyMny) {
        this.dailyMny = dailyMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    @ReferSerialTransfer(referCode = "bfyj-onsite")
    public Long getOnSiteId() {
        return onSiteId;
    }
    @ReferDeserialTransfer
    public void setOnSiteId(Long onSiteId) {
        this.onSiteId = onSiteId;
    }
    public Integer getOnSiteDays() {
        return onSiteDays;
    }

    public void setOnSiteDays(Integer onSiteDays) {
        this.onSiteDays = onSiteDays;
    }
    public BigDecimal getOnSiteMny() {
        return onSiteMny;
    }

    public void setOnSiteMny(BigDecimal onSiteMny) {
        this.onSiteMny = onSiteMny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}
